// java wrapper for vtkContextView object
//

package vtk;
import vtk.*;

public class vtkContextView extends vtkRenderViewBase
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetContext_2(vtkContext2D id0);
  public void SetContext(vtkContext2D id0)
    { SetContext_2(id0); }

  private native long GetContext_3();
  public vtkContext2D GetContext() {
    long temp = GetContext_3();

    if (temp == 0) return null;
    return (vtkContext2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScene_4(vtkContextScene id0);
  public void SetScene(vtkContextScene id0)
    { SetScene_4(id0); }

  private native long GetScene_5();
  public vtkContextScene GetScene() {
    long temp = GetScene_5();

    if (temp == 0) return null;
    return (vtkContextScene)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkContextView() { super(); }

  public vtkContextView(long id) { super(id); }
  public native long   VTKInit();

}
